==> download.php?d=bsmyjspace_pack_2.6.0_PACK.zip: admin/views/tools/tmpl/default.php <==
<?php
/**
* @version $Id: default.php $
* @version		2.6.0 14/07/2016
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2011-2012-2013-2014-2015-2016 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;

if (version_compare(JVERSION, '3.4.0', 'ge'))
	JHtml::_('bootstrap.tooltip');

$document = JFactory::getDocument();
$document->addStyleSheet(JURI::root(true).'/components/com_myjspace/assets/myjspace.min.css');
$nb_tools = 0;
?>
<?php if (!empty($this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif;?>
<div class="myjspace myjsp-w-100">
	<fieldset class="adminform">
	<legend><?php echo JText::_('COM_MYJSPACE_TOOLS');?></legend>
	<table class="adminlist table-striped">
<?php
	// Default tools for page folders
	if ($this->link_folder == 1) {
		$nb_tools = 3;
?>
		<tr>
			<td class="<?php echo "row1"; ?>">
				<a class="btn myjspbtn300l" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_EMPTY_PAGES'); ?>" href="index.php?option=com_myjspace&amp;task=adm_delete_empty_pages&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-remove"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_EMPTY_PAGES'); ?></span>
				</a>
			</td>
		</tr>
		<tr>
			<td class="<?php echo "row0"; ?>">
				<a class="btn myjspbtn300l" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_FOLDER'); ?>" href="index.php?option=com_myjspace&amp;task=adm_delete_folder&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-remove"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_FOLDER'); ?></span>
				</a>
			</td>
		</tr>
		<tr>
			<td class="<?php echo "row0"; ?>">
				<a class="btn myjspbtn300l btn-primary" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_CREATE_FOLDER'); ?>" href="index.php?option=com_myjspace&amp;task=adm_create_folder&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-loop"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_CREATE_FOLDER'); ?></span>
				</a>
			</td>
		</tr>
<?php
	}

	if ($this->POtherTools) {
		foreach ($this->POtherTools as $id0 => $label0) {
			foreach ($this->POtherTools[$id0] as $id => $label) {
				if (isset($label['label'])) {
?>				
		<tr>
			<td class="row0">
				<a class="btn myjspbtn300l <?php if (isset($label['class'])) echo $label['class']; ?>" title="<?php echo $label['label']; ?>" href="index.php?option=com_myjspace&amp;task=other_tools&amp;id=<?php echo $id; ?>&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-apply"></i>
					<span><?php echo $label['label']; ?></span>
				</a>
			</td>
		</tr>
<?php			
				}
			}
		}		
	}
?>

	</table>
<?php
	if ($nb_tools == 0)
		echo JText::_('COM_MYJSPACE_ADMIN_LINK_MSG');
?>
	</fieldset>
		
</div>
</div>

==> download.php?d=bsmyjspace_pack_2.6.4_PACK.zip: admin/views/tools/tmpl/default.php <==
<?php
/**
* @version $Id: default.php $
* @version		2.6.3 18/07/2018
* @package		com_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010-2011-2012-2013-2014-2015-2016-2017-2018 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die;

if (version_compare(JVERSION, '3.4.0', 'ge'))
	JHtml::_('bootstrap.tooltip');

$document = JFactory::getDocument();
$document->addStyleSheet(JURI::root(true).'/components/com_myjspace/assets/myjspace.min.css');
$nb_tools = 0;
?>
<?php if (!empty($this->sidebar)) : ?>
	<div id="j-sidebar-container" class="span2">
		<?php echo $this->sidebar; ?>
	</div>
	<div id="j-main-container" class="span10">
<?php else : ?>
	<div id="j-main-container">
<?php endif;?>
<div class="myjspace myjsp-w-100">
	<fieldset class="adminform">
	<legend><?php echo JText::_('COM_MYJSPACE_TOOLS');?></legend>
	<table class="adminlist table-striped">
<?php
	// Default tools for page folders
	if ($this->link_folder == 1) {
		$nb_tools = 3;
?>
		<tr>
			<td class="<?php echo "row1"; ?>">
				<a class="btn myjspbtn300l" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_EMPTY_PAGES'); ?>" href="index.php?option=com_myjspace&amp;task=adm_delete_empty_pages&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-purge"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_EMPTY_PAGES'); ?></span>
				</a>
			</td>
		</tr>
		<tr>
			<td class="<?php echo "row0"; ?>">
				<a class="btn myjspbtn300l" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_FOLDER'); ?>" href="index.php?option=com_myjspace&amp;task=adm_delete_folder&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-purge"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_DELETE_FOLDER'); ?></span>
				</a>
			</td>
		</tr>
		<tr>
			<td class="<?php echo "row0"; ?>">
				<a class="btn myjspbtn300l btn-primary" title="<?php echo JText::_('COM_MYJSPACE_ADMIN_CREATE_FOLDER'); ?>" href="index.php?option=com_myjspace&amp;task=adm_create_folder&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-loop"></i>
					<span><?php echo JText::_('COM_MYJSPACE_ADMIN_CREATE_FOLDER'); ?></span>
				</a>
			</td>
		</tr>
<?php
	}

	if ($this->POtherTools) {
		foreach ($this->POtherTools as $id0 => $label0) {
			foreach ($this->POtherTools[$id0] as $id => $label) {
				if (isset($label['label'])) {
?>				
		<tr>
			<td class="row0">
				<a class="btn myjspbtn300l <?php if (isset($label['class'])) echo $label['class']; ?>" title="<?php echo $label['label']; ?>" href="index.php?option=com_myjspace&amp;task=other_tools&amp;id=<?php echo $id; ?>&amp;<?php echo BS_Util::getFormToken();?>=1">
					<i class="icon-apply"></i>
					<span><?php echo $label['label']; ?></span>
				</a>
			</td>
		</tr>
<?php			
				}
			}
		}		
	} else {
?>
		<tr>
			<td class="<?php echo "row0"; ?>">
			&nbsp;
			</td>
		</tr>
		<tr>
			<td class="<?php echo "row0"; ?>">
				&nbsp;<?php echo JText::_('COM_MYJSPACE_ADMIN_NO_EXTRA_TOOL'); ?>
			</td>
		</tr>
<?php
	}
?>

	</table>
<?php
	if ($nb_tools == 0)
		echo JText::_('COM_MYJSPACE_ADMIN_LINK_MSG');
?>
	</fieldset>
		
</div>
</div>
